# Changelog
This file keeps track of all notable changes between the different versions of cpe_search.

## v0.1.2 - 2025-11-18
### Fixed
- GitHub workflow to publish PyPI package uses more recent action versions

## v0.1.1 - 2025-11-18
### Added
- GitHub workflow to automatically publish a package to PyPI on new release

## v0.1.0 - 2025-11-17
### Added
- Initial release
